@@ -12,14 +12,18 @@
   id durationText;
   id repeat;
   id endDate;
-  id endDateStepper;
   id location;
   id store;
   id allDay;
+  id ok;
+  id until;
+  Date *startDate;
 }
 
 - (BOOL)editAppointment:(Event *)data withStoreManager:(StoreManager *)sm;
 - (void)validate:(id)sender;
 - (void)cancel:(id)sender;
-
+- (void)selectFrequency:(id)sender;
+- (void)toggleUntil:(id)sender;
+- (void)toggleAllDay:(id)sender;
 @end
