@@ -77,4 +77,9 @@
 {
   return [_attributes valueForKey:key];
 }
+
+- (void)sortChildrenUsingFunction:(int (*)(id, id, void *))compare context:(void *)context
+{
+  [_children sortUsingFunction:compare context:context];
+}
 @end
