@@ -3,16 +3,13 @@
 #import <AppKit/AppKit.h>
 #import "ConfigManager.h"
 #import "Event.h"
-
-@protocol DayViewDataSource
-- (NSSet *)scheduledAppointmentsForDayView;
-@end
+#import "StoreManager.h"
 
 @class AppointmentView;
 
 @interface DayView : NSView <ConfigListener>
 {
-  id <DayViewDataSource> _dataSource;
+  IBOutlet id <AgendaDataSource> dataSource;
   IBOutlet id delegate;
   int _firstH;
   int _lastH;
@@ -25,21 +22,22 @@
   NSColor *_alternateBackgroundColor;
 }
 
-- (id)initWithFrame:(NSRect)frameRect;
-- (void)drawRect:(NSRect)rect;
+- (void)selectAppointmentView:(AppointmentView *)aptv;
+- (NSRect)frameForAppointment:(Event *)apt;
+- (int)minuteToPosition:(int)minutes;
+- (int)positionToMinute:(float)position;
+- (int)roundMinutes:(int)minutes;
+- (id)delegate;
 - (void)reloadData;
-- (Event *)selectedAppointment;
 - (int)firstHour;
 - (int)lastHour;
 - (int)minimumStep;
-
+- (void)deselectAll:(id)sender;
 @end
 
 @interface NSObject(DayViewDelegate)
-
 - (void)dayView:(DayView *)dayview editEvent:(Event *)event;
 - (void)dayView:(DayView *)dayview modifyEvent:(Event *)event;
 - (void)dayView:(DayView *)dayview createEventFrom:(int)start to:(int)end;
 - (void)dayView:(DayView *)dayview selectEvent:(Event *)event;
-
 @end
