@@ -15,6 +15,7 @@
   IBOutlet id minStepText;
   IBOutlet id storePopUp;
   IBOutlet id storeColor;
+  IBOutlet id storeTextColor;
   IBOutlet id defaultStorePopUp;
   IBOutlet id storeDisplay;
   IBOutlet id storeWritable;
@@ -22,6 +23,11 @@
   IBOutlet id storeClass;
   IBOutlet id storeName;
   IBOutlet id createButton;
+  IBOutlet NSBox *slot;
+  IBOutlet id globalPreferences;
+  IBOutlet id storePreferences;
+  IBOutlet id storeFactory;
+  IBOutlet id itemPopUp;
   StoreManager *_sm;
 }
 
@@ -30,6 +36,7 @@
 
 -(void)selectStore:(id)sender;
 -(void)changeColor:(id)sender;
+-(void)changeTextColor:(id)sender;
 -(void)changeStart:(id)sender;
 -(void)changeEnd:(id)sender;
 -(void)changeStep:(id)sender;
@@ -38,5 +45,6 @@
 -(void)toggleWritable:(id)sender;
 -(void)removeStore:(id)sender;
 -(void)createStore:(id)sender;
+-(void)selectItem:(id)sender;
 
 @end
