@@ -10,7 +10,7 @@
    This application is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License.
+   version 2 of the License or any later version.
  
    This application is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -22,10 +22,11 @@
    Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA.
 */
 
-#include <AppKit/AppKit.h>
+#import <AppKit/AppKit.h>
 
 int main(int argc, const char *argv[])
 {
+  //[NSObject enableDoubleReleaseCheck:YES];
   return NSApplicationMain (argc, argv);
 }
 
