@@ -1,7 +1,7 @@
 /* emacs buffer mode hint -*- objc -*- */
 
 #import <Foundation/Foundation.h>
-#import "Event.h"
+#import "Element.h"
 #import "ical.h"
 
 @interface iCalTree : NSObject
@@ -10,10 +10,12 @@
 }
 
 - (BOOL)parseString:(NSString *)string;
+- (BOOL)parseData:(NSData *)data;
 - (NSString *)iCalTreeAsString;
-- (NSSet *)events;
-- (BOOL)add:(Event *)event;
-- (BOOL)remove:(Event *)event;
-- (BOOL)update:(Event *)event;
+- (NSData *)iCalTreeAsData;
+- (NSSet *)components;
+- (BOOL)add:(Element *)event;
+- (BOOL)remove:(Element *)event;
+- (BOOL)update:(Element *)event;
 @end
 
